
Changelog
=========

0.4.0.rc.1 (2020-04-04)
-----------------------

* Move the code of the oemof.tools repository to a stand-alone repository.
* Use cookiecutter to create a wider testing structure and a more standardised
  package structure.
